 .demoHeaders {
		margin-top: 2em;
	}

	#dialog-link {
		padding: .4em 1em .4em 20px;
		text-decoration: none;
		position: relative;
	}
	#dialog-link span.ui-icon {
		margin: 0 5px 0 0;
		position: absolute;
		left: .2em;
		top: 50%;
		margin-top: -8px;
	}
	
#imgOSDDialog:hover{
	cursor: pointer;
}


.imgOSDStatus:hover{
	cursor: pointer;
}

.img_popover:hover{
	cursor: pointer;
	border: none;
	text-decoration: none;
}

.img_popover:focus{
	cursor: pointer;
	border: 0px;
	text-decoration: none;
}


#divOSDInfo{
	width: 400px;
	height: 600px;
	/*border: 1px solid #ccc;*/
	float:none;
}

#divBaiscInfo{
	height:100px;
}

#tSmartInfo>thead>tr{
	border:0px;
}


#tSmartInfo>thead>tr>th{
	border:1px solid #ccc;
	text-align:center;

}



.form-group{
  display: block;
  height: 20px;
}

.span-label{
	min-width: 150px;
	display:inline-block;
}

#tSmartInfo>tbody>tr>td{
	width: 150px;
	height:30px;
	border: 1px solid #ccc
}

.page{
	float:right;
}

.smart-info-icon{
	margin-left:10px; .demoHeaders {
		margin-top: 2em;
	}

	#dialog-link {
		padding: .4em 1em .4em 20px;
		text-decoration: none;
		position: relative;
	}
	#dialog-link span.ui-icon {
		margin: 0 5px 0 0;
		position: absolute;
		left: .2em;
		top: 50%;
		margin-top: -8px;
	}

#imgOSDDialog:hover{
	cursor: pointer;
}


#divOSDInfo{
	width: 400px;
	height: 600px;
	/*border: 1px solid #ccc;*/
	float:none;
}

#divBaiscInfo{
	height:100px;
}

#tSmartInfo>thead>tr{
	border:0px;
}


#tSmartInfo>thead>tr>th{
	border:1px solid #ccc;
	text-align:center;

}



.form-group{
  display: block;
  height: 20px;
}

.span-label{
	min-width: 150px;
	display:inline-block;
}

#tSmartInfo>tbody>tr>td{
	width: 150px;
	height:30px;
	border: 1px solid #ccc
}

.page{
	float:right;
}

.smart-info-icon{
	margin-left:10px;
	cursor:pointer;
}





.form-label{
	width: 60px;
}

.form-required{
	content: "*";
  	font-weight: bold;
  	line-height: 0;
  	padding-left: 4px;
  	color: #428bca;
}

#divAddOSDForm{
	width: 800px;
	margin-top: 10px;
	overflow: hidden;
	padding: 5px;
}

.left{
	margin-right: 50px;
}

.control-group{
	margin-top: 10px;
}

label{
	color:#555555;
}
