{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Import Cluster" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Import Cluster") %}
{% endblock page_header %}

{% block main %}
   {{table.render}}
{% endblock %}

{% block js %}
    {{ block.super }}
    <script src="{{ STATIC_URL }}dashboard/js/importcluster.mainpage.js"></script>

{% endblock %}

