#divPieChartsContent{
	width: 100%;
	height: auto;
	/*border: 1px solid red;*/
}

#divStandardSettingsContent{
	width: 100%;
	height: 30px;
	/*border: 1px solid red;*/
	padding-left: 10px;
}


.pie-chart{
	margin-left: 10px;
	margin-top: 10px;
	width: 150px;
	height: 150px;
	display: inline-block;
	/*border: 1px solid #ccc;*/
}

#tSettings>tbody>tr>td{
	width: 200px;
}