
{% load datepicker_locale from horizon %}
{% datepicker_locale as DATEPICKER_LOCALE %}

<script src='{{ STATIC_URL }}lib/jquery-1.10.2.js' type='text/javascript' charset='utf-8'></script>
<script src='{{ STATIC_URL }}horizon/js/horizon.js' type='text/javascript' charset='utf-8'></script>


<script type='text/javascript' charset='utf-8'>
    // make translation info available on client
    horizon.languageCode = '{{ LANGUAGE_CODE }}';
    horizon.languageBidi = '{{ LANGUAGE_BIDI }}';
    horizon.datepickerLocale = '{{ DATEPICKER_LOCALE }}';
    STATIC_URL= '{{ STATIC_URL }}';

    /* Load angular modules extensions list before we include angular/horizon.js */
    var angularModuleExtension = {{ HORIZON_CONFIG.angular_modules|default:"[]"|safe}};
    horizon.conf={  ajax:
      { queue_limit: {{ HORIZON_CONFIG.ajax_queue_limit|default:"null" }} },
            auto_fade_alerts: {
      delay: {{ HORIZON_CONFIG.auto_fade_alerts.delay|default:"3000" }},
      fade_duration: {{ HORIZON_CONFIG.auto_fade_alerts.fade_duration|default:"1500" }},
      types: {{ HORIZON_CONFIG.auto_fade_alerts.types|default:"[]"|safe }},
       spinner_options: {
        inline: {
          lines:  10,
          length: 5,
          width:  2,
          radius: 3,
          color:  '#000',
          speed:  0.8,
          trail:  50,
          zIndex: 100
        },
        modal: {
          lines:  10,
          length: 15,
          width:  4,
          radius: 10,
          color:  '#000',
          speed:  0.8,
          trail:  50
        },
        line_chart: {
          lines:  10,
          length: 15,
          width:  4,
          radius: 11,
          color:  '#000',
          speed:  0.8,
          trail:  50
        }
      }

    }
    };
</script>



