
<!-- Copyright 2014 Intel Corporation, All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the"License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied. See the License for the
 specific language governing permissions and limitations
 under the License.
 --> 

{% extends "horizon/common/_modal.html" %}
{% load i18n %}

{% block form_id %}create_storage_pool_form{% endblock %}
{% block form_action %}{% url 'horizon:vsm:storageservermgmt:addhosts' %}{% endblock %}

{% block modal-header %}{% trans "Add Servers" %}{% endblock %}
{% block modal_id %}create_storage_pool_modal{% endblock %}

{% block modal-body %}
 {% csrf_token %}
 {{ table.render }}
{% endblock %}

{% block modal-footer %}
  <input class="btn btn-primary pull-right add-server-commit" type="submit" value="{% trans "Add Servers" %}" />
  <a href="{% url 'horizon:vsm:storageservermgmt:index' %}" class="btn secondary cancel close">{% trans "Cancel" %}</a>
{% endblock %}

