
<!-- Copyright 2014 Intel Corporation, All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the"License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied. See the License for the
 specific language governing permissions and limitations
 under the License.
 --> 

{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Update User" %}{% endblock %}

{% block page_header %}
  {# to make searchable false, just remove it from the include statement #}
  {% include "horizon/common/_page_header.html" with title=_("Update User") %}

   <link href="{{ STATIC_URL }}dashboard/css/user.css" rel="stylesheet">
{% endblock page_header %}

{% block main %}
    {% csrf_token %}


<div id="divUserForm" >
  <div id="divWarningInfo" class="alert alert-warning" role="alert">
      <!-- some warning info -->
  </div>

      <form>
        <div class="left">
          <fieldset>
          {% include "horizon/common/_form_fields.html" %}
          </fieldset>
        </div>
        <div class="right">
          <h3>{% trans "Description" %}:</h3>
          <p>{% trans "From here you can edit the user's details." %}</p>
          <p>{% trans "Your Password Must contain at least one number, one uppercase character, one lowercase character and one special character (eg @#$%^&*.:;~\|[]{} )." %}</p>
        </div>
      </form>


      <div id="divFormOptions" class="vsm-options-bar">
          <input id="lblUpdateUser" type="hidden" value="{{ user.username }}"/>
          <input id="lblLoginUser" type="hidden" value="{{ request.user.username }}"/>
          <input id="btnUpdateUser"  class="btn btn-primary" type="submit" value="{% trans 'Update User' %}" />
          <a id="btnCancel" class="btn btn-default" href="/dashboard/vsm/usermgmt/">{% trans 'Cancel' %}</a>
      </div>
</div>

{% endblock %}


{% block js %}
    {{ block.super }}
    <script src='{{ STATIC_URL }}dashboard/js/vsm.spin.js' type='text/javascript' charset='utf-8'></script>
    <script src="{{ STATIC_URL }}dashboard/js/user.js"></script> 
{% endblock %}

