
<!-- Copyright 2014 Intel Corporation, All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the"License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied. See the License for the
 specific language governing permissions and limitations
 under the License.
 --> 

{% extends 'base.html' %}
{% load i18n %}
{% block title %}Update OpenStack Access{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Update OpenStack Access") %}
  <link href="{{ STATIC_URL }}dashboard/css/openstackconnect.css" rel="stylesheet">

{% endblock page_header %}

{% block main %}
    {% csrf_token %}
    <div id="divPoolForm" >
	    <form>
	    	<div class="left">
		    <fieldset>
		    	{% include "horizon/common/_form_fields.html" %}
		    </fieldset>
			</div>
			<div class="right">
			    <h3>{% trans "Description" %}:</h3>
                <p>
                    {% trans "For Keystone V2.0, An Example AS Followed:" %}<br>
                    {% trans "Tenant Name: admin" %}<br>
                    {% trans "UserName: admin" %}<br>
                    {% trans "Password: ******" %}<br>
                    {% trans "Auth Url: http://10.0.0.10:5000/v2.0" %}<br>
                    {% trans "Region Name: RegionOne" %}<br>
                    {% trans "SSH User Name: root" %}
                </p>
                <p>
                    {% trans "For Keystone V3, An Example AS Followed:" %}<br>
                    {% trans "Tenant Name: 9b62326e927a4973891d6daed73979f0(ID of Project)" %}<br>
                    {% trans "UserName: 200c46b79086408e95ce50e617662119(ID of User)" %}<br>
                    {% trans "Password: ******" %}<br>
                    {% trans "Auth Url: http://10.0.0.10:35357/v3" %}<br>
                    {% trans "Region Name: RegionOne" %}<br>
                    {% trans "SSH User Name: root" %}
                </p>
                <p>
                    {% trans "PS: The Region Name can be blank if you only have one region." %}
                </p>
			</div>
		</form>
		 <div id="divFormOptions" class="vsm-options-bar">
	    	<button id="btnUpdate" class="btn btn-primary">{% trans "Submit" %}</button>
	    	<a id="btnCancel" class="btn btn-default" href="/dashboard/vsm/openstackconnect/">{% trans "Cancel" %}</a>
	    </div>
	</div>
{% endblock %}


{% block js %}
    {{ block.super }}
	<script src='{{ STATIC_URL }}dashboard/js/vsm.spin.js' type='text/javascript' charset='utf-8'></script>
    <script src="{{ STATIC_URL }}dashboard/js/openstackconnect.js"></script> 
{% endblock %}

